summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2025-06-26 21:59:25 +0300
committerPaul Buetow <paul@buetow.org>2025-06-26 21:59:25 +0300
commit1e643ac66765fc0ab4224335191731d8b77fece2 (patch)
tree00f041a72855e8a43876ec9f4c9531896dccaa03
parent45613574ddfc6203ca31388ee7f6c60423f1cbd2 (diff)
feat: increase profiling test data sizes for meaningful results
- profile_benchmarks.sh: Increased test data sizes - Small log: 1MB → 10MB - Medium log: 10MB → 100MB - CSV file: 10MB → 50MB - DTail format log: 1,000 lines → 100,000 lines - profile_dmap.sh: Already updated (1K and 1M lines) These larger datasets ensure that profiling runs long enough to collect meaningful performance data, especially for dmap which was finishing too quickly with the smaller datasets. 🤖 Generated with [Claude Code](https://claude.ai/code) Co-Authored-By: Claude <noreply@anthropic.com>
-rwxr-xr-xprofiling/profile_benchmarks.sh12
-rwxr-xr-xprofiling/profile_dmap.sh4
2 files changed, 8 insertions, 8 deletions
diff --git a/profiling/profile_dmap.sh b/profiling/profile_dmap.sh
index 03402e1..2702dee 100755
--- a/profiling/profile_dmap.sh
+++ b/profiling/profile_dmap.sh
@@ -82,8 +82,8 @@ generate_dtail_format_data() {
fi
}
-generate_dtail_format_data "$TEST_DATA_DIR/stats_small.log" 100
-generate_dtail_format_data "$TEST_DATA_DIR/stats_medium.log" 1000
+generate_dtail_format_data "$TEST_DATA_DIR/stats_small.log" 1000
+generate_dtail_format_data "$TEST_DATA_DIR/stats_medium.log" 1000000
# Build dmap
echo -e "${GREEN}Building commands...${NC}"
diff --git a/profiling/profile_benchmarks.sh b/profiling/profile_benchmarks.sh
index d3fcabd..78cc587 100755
--- a/profiling/profile_benchmarks.sh
+++ b/profiling/profile_benchmarks.sh
@@ -72,16 +72,16 @@ run_profile() {
# Generate test data
echo -e "${GREEN}Preparing test data...${NC}"
-generate_test_data "1MB" "$TEST_DATA_DIR/small.log"
-generate_test_data "10MB" "$TEST_DATA_DIR/medium.log"
+generate_test_data "10MB" "$TEST_DATA_DIR/small.log"
+generate_test_data "100MB" "$TEST_DATA_DIR/medium.log"
# Skip large file for faster testing
# generate_test_data "1GB" "$TEST_DATA_DIR/large.log"
# Generate CSV data for dmap (smaller size for faster processing)
if [ ! -f "$TEST_DATA_DIR/test.csv" ]; then
echo -e "${YELLOW}Generating CSV test data${NC}"
- echo " Command: go run ../benchmarks/cmd/generate_profile_data.go -size \"10MB\" -output \"$TEST_DATA_DIR/test.csv\" -format csv"
- go run ../benchmarks/cmd/generate_profile_data.go -size "10MB" -output "$TEST_DATA_DIR/test.csv" -format csv
+ echo " Command: go run ../benchmarks/cmd/generate_profile_data.go -size \"50MB\" -output \"$TEST_DATA_DIR/test.csv\" -format csv"
+ go run ../benchmarks/cmd/generate_profile_data.go -size "50MB" -output "$TEST_DATA_DIR/test.csv" -format csv
fi
echo
@@ -117,8 +117,8 @@ echo -e "${GREEN}=== Profiling dmap ===${NC}"
if [ ! -f "$TEST_DATA_DIR/dtail_format.log" ]; then
echo -e "${YELLOW}Generating DTail format test data for dmap${NC}"
echo " Command: Creating DTail format log file"
- # Generate DTail default format log lines
- for i in $(seq 1 1000); do
+ # Generate DTail default format log lines (100K lines for meaningful profiling)
+ for i in $(seq 1 100000); do
hostname="host$((i % 10))"
goroutines=$((40 + i % 40))
cgocalls=$((i % 100))